[llvm-commits] CVS: llvm/include/llvm/Analysis/Expressions.h

Chris Lattner lattner at cs.uiuc.edu
Tue Dec 23 02:04:01 PST 2003


Changes in directory llvm/include/llvm/Analysis:

Expressions.h updated: 1.9 -> 1.10

---
Log message:

Rename ClassifyExpression -> ClassifyExpr


---
Diffs of the changes:  (+6 -6)

Index: llvm/include/llvm/Analysis/Expressions.h
diff -u llvm/include/llvm/Analysis/Expressions.h:1.9 llvm/include/llvm/Analysis/Expressions.h:1.10
--- llvm/include/llvm/Analysis/Expressions.h:1.9	Tue Nov 11 16:41:31 2003
+++ llvm/include/llvm/Analysis/Expressions.h	Tue Dec 23 02:03:40 2003
@@ -9,8 +9,8 @@
 //
 // This file defines a package of expression analysis utilties:
 //
 // ClassifyExpression: Analyze an expression to determine the complexity of the
 //   expression, and which other variables it depends on.  
 // 
 //===----------------------------------------------------------------------===//
 
@@ -25,10 +25,10 @@
 
 struct ExprType;
 
-// ClassifyExpression: Analyze an expression to determine the complexity of the
-// expression, and which other values it depends on.  
-//
-ExprType ClassifyExpression(Value *Expr);
+/// ClassifyExpr: Analyze an expression to determine the complexity of the
+/// expression, and which other values it depends on.
+///
+ExprType ClassifyExpr(Value *Expr);
 
 // ExprType - Represent an expression of the form CONST*VAR+CONST
 // or simpler.  The expression form that yields the least information about the
@@ -9,8 +9,8 @@
 // This file defines a package of expression analysis utilties:
 //
-// ClassifyExpression: Analyze an expression to determine the complexity of the
-//   expression, and which other variables it depends on.  
+// ClassifyExpr: Analyze an expression to determine the complexity of the
+// expression, and which other variables it depends on.
 // 
 //===----------------------------------------------------------------------===//





More information about the llvm-commits mailing list